$stm_base_color: #002e5b;
$stm_secondary_color: #6c98e1;
$stm_third_color: #fde428;

//skin_turquoise
//$stm_base_color: #006b63;
//$stm_secondary_color: #99c0bd;
//$stm_third_color: #fcba37;

//skin_dark_denim
//$stm_base_color: #2a2b35;
//$stm_secondary_color: #f7df2a;
//$stm_third_color: #f7df2a;

//skin_arctic_black
//$stm_base_color: #222222;
//$stm_secondary_color: #aaaaaa;
//$stm_third_color: #82d1e5;